STANNIX Solutions for the Real World


Manual: git-switch

GIT-SWITCH(1)					 Git Manual				       GIT-SWITCH(1)

NAME
       git-switch - Switch branches

SYNOPSIS
       git switch [] [--no-guess] 
       git switch [] --detach []
       git switch [] (-c|-C)  []
       git switch [] --orphan 

DESCRIPTION
       Switch to a specified branch. The working tree and the index are updated to match the branch. All new
       commits will be added to the tip of this branch.

       Optionally a new branch could be created with either -c, -C, automatically from a remote branch of
       same name (see --guess), or detach the working tree from any branch with --detach, along with
       switching.

       Switching branches does not require a clean index and working tree (i.e. no differences compared to
       HEAD). The operation is aborted however if the operation leads to loss of local changes, unless told
       otherwise with --discard-changes or --merge.

OPTIONS
       
	   Branch to switch to.

       
	   Name for the new branch.

       
	   The starting point for the new branch. Specifying a  allows you to create a branch
	   based on some other point in history than where HEAD currently points. (Or, in the case of
	   --detach, allows you to inspect and detach from some other point.)

	   You can use the @{-} syntax to refer to the -th last branch/commit switched to using git
	   switch or git checkout operation. You may also specify - which is synonymous to @{-1}. This is
	   often used to switch quickly between two branches, or to undo a branch switch by mistake.

	   As a special case, you may use ... as a shortcut for the merge base of  and
	    if there is exactly one merge base. You can leave out at most one of  and ,
	   in which case it defaults to HEAD.

       -c , --create 
	   Create a new branch named  starting at  before switching to the branch.
	   This is the transactional equivalent of

	       $ git branch 
	       $ git switch 

	   that is to say, the branch is not reset/created unless git switch is successful (e.g., when the
	   branch is in use in another worktree, not just the current branch stays the same, but the branch
	   is not reset to the start-point, either).

       -C , --force-create 
	   Similar to --create except that if  already exists, it will be reset to
	   . This is a convenient shortcut for:

	       $ git branch -f __
	       $ git switch __

       -d, --detach
	   Switch to a commit for inspection and discardable experiments. See the "DETACHED HEAD" section in
	   git-checkout(1) for details.

       --guess, --no-guess
	   If  is not found but there does exist a tracking branch in exactly one remote (call it
	   ) with a matching name, treat as equivalent to

	       $ git switch -c  --track /

	   If the branch exists in multiple remotes and one of them is named by the checkout.defaultRemote
	   configuration variable, we’ll use that one for the purposes of disambiguation, even if the
	    isn’t unique across all remotes. Set it to e.g.  checkout.defaultRemote=origin to always
	   checkout remote branches from there if  is ambiguous but exists on the origin remote. See
	   also checkout.defaultRemote in git-config(1).

	   --guess is the default behavior. Use --no-guess to disable it.

	   The default behavior can be set via the checkout.guess configuration variable.

       -f, --force
	   An alias for --discard-changes.

       --discard-changes
	   Proceed even if the index or the working tree differs from HEAD. Both the index and working tree
	   are restored to match the switching target. If --recurse-submodules is specified, submodule
	   content is also restored to match the switching target. This is used to throw away local changes.

       -m, --merge
	   If you have local modifications to one or more files that are different between the current
	   branch and the branch to which you are switching, the command refuses to switch branches in order
	   to preserve your modifications in context. However, with this option, a three-way merge between
	   the current branch, your working tree contents, and the new branch is done, and you will be on
	   the new branch.

	   When a merge conflict happens, the index entries for conflicting paths are left unmerged, and you
	   need to resolve the conflicts and mark the resolved paths with git add (or git rm if the merge
	   should result in deletion of the path).

       --conflict=